/*-----------------------------------------------------------------------------
*         ATMEL Microcontroller Software Support  -  ROUSSET  -
*------------------------------------------------------------------------------
* The software is delivered "AS IS" without warranty or condition of any
* kind, either express, implied or statutory. This includes without
* limitation any warranty or condition with respect to merchantability or
* fitness for any particular purpose, or against the infringements of
* intellectual property rights of others.
*------------------------------------------------------------------------------
* File Name           : init.c
* Object              : DBUG utility
* Creation            : JPP   02/Jul/2004
*----------------------------------------------------------------------------*/

/* Include Standard LIB  files */
#include "../Board.h"
#include "init.h"
/*-----------------------------------------------------------------------------
* Function Name       : Trace_Toggel_LED
* Object              : Toggel a LED
*----------------------------------------------------------------------------*/
void Trace_Toggel_LED (unsigned int Led)
{
    if ( (AT91F_PIO_GetInput(AT91C_BASE_PIOA) & Led ) == Led )
    {
        AT91F_PIO_ClearOutput( AT91C_BASE_PIOA, Led );
    }
    else
    {
        AT91F_PIO_SetOutput( AT91C_BASE_PIOA, Led );
    }
}

/*-----------------------------------------------------------------------------
* \fn    AT91F_DBGU_Init
* \brief This function is used to send a string through the DBGU channel
* (Very low level debugging)
*----------------------------------------------------------------------------*/
void AT91F_DBGU_Init(void)
{
    /* Open PIO for DBGU */
    AT91F_DBGU_CfgPIO();

    /* Configure DBGU */
    AT91F_US_Configure (
		(AT91PS_USART) AT91C_BASE_DBGU,   /* DBGU base address */
		MCK,
		AT91C_US_ASYNC_MODE ,      /* Mode Register to be programmed */
		AT91C_DBGU_BAUD ,          /* Baudrate to be programmed */
		0);                        /* Timeguard to be programmed */

    /* Enable Transmitter & receivier */
    ((AT91PS_USART)AT91C_BASE_DBGU)->US_CR = AT91C_US_RXEN | AT91C_US_TXEN;
}

/*-----------------------------------------------------------------------------
* Function Name       : AT91F_DBGU_Get
* Object              : Get a string to USART manage Blackspace and echo
* Input Parameters    : com descriptor, type string & val return value
* Output Parameters   : none
*----------------------------------------------------------------------------*/
unsigned int AT91F_DBGU_Get( char *val)
{
    if ((AT91F_US_RxReady((AT91PS_USART)AT91C_BASE_DBGU)) == 0)
        return (1);
    else
    {
        *val= AT91F_US_GetChar((AT91PS_USART)AT91C_BASE_DBGU);
        return (0);
    }
}

/*-----------------------------------------------------------------------------
* Function Name       : AT91F_DBGU_scanf
* Object              : Get a string to USART manage Blackspace and echo
* Input Parameters    : com descriptor, type string & val return value
* Output Parameters   : none
*----------------------------------------------------------------------------*/
void AT91F_DBGU_scanf(char * type,unsigned int * val)
{
    unsigned int read = 0;
    char buff[10];
    unsigned int nb_read =0;

    while( (read != 0x0D) & (nb_read != sizeof(buff)) ) {
        /* wait the USART Ready for reception */
	 while((AT91C_BASE_DBGU->DBGU_CSR  & AT91C_US_RXRDY) == 0 ) ;
        /* Get a char */
	read = AT91C_BASE_DBGU->DBGU_RHR ;
        buff[nb_read]= (char)read;
        /* Manage Blackspace */
        while((AT91C_BASE_DBGU->DBGU_CSR & AT91C_US_TXRDY) ==0)  {}
        if ((char)read == 0x08) {
            if ( nb_read != 0 ) {
              nb_read--;
              AT91C_BASE_DBGU->DBGU_THR = read;
            }
        }
        else {
          /* echo */
          AT91C_BASE_DBGU->DBGU_THR = read;
          nb_read++;
        }
    }
    /* scan the value */
    sscanf(buff,type,val);
}

/*-----------------------------------------------------------------------------
* \fn    AT91F_DBGU_Printk
* \brief This function is used to send a string through the DBGU channel
* (Very low level debugging)
*----------------------------------------------------------------------------*/
void AT91F_DBGU_Printk( char *buffer) /*\arg pointer to a string ending by \0*/
{
	while(*buffer != '\0') {
		while (!AT91F_US_TxReady((AT91PS_USART)AT91C_BASE_DBGU));
		AT91F_US_PutChar((AT91PS_USART)AT91C_BASE_DBGU, *buffer++);
	}
}

